@@ -15,9 +15,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this package; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef SPEECHD_TYPES_H
@@ -106,6 +104,7 @@ typedef enum {
 typedef struct {
 	signed int rate;
 	signed int pitch;
+	signed int pitch_range;
 	signed int volume;
 
 	SPDPunctuation punctuation_mode;
