@@ -15,8 +15,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 import argparse
 import datetime
@@ -122,7 +121,8 @@ def question_with_required_answers(text, default, required):
 
 def setup_argparse():
     """Set up an argparser instance with all the options accepted."""
-    parser = argparse.ArgumentParser()
+    parser = argparse.ArgumentParser(
+        description=_('A simple tool for basic configuration of Speech Dispatcher and problem diagnostics'))
     parser.add_argument('-u', '--create-user-conf',
         dest='create_user_configuration', action="store_true", default=False,
         help=_("Create Speech Dispatcher configuration for the given user"))
@@ -158,6 +158,9 @@ def setup_argparse():
     parser.add_argument('-D', '--debug', dest='debug',
             action="store_true", default=False,
             help=_("Debug a problem and generate a report"))
+    parser.add_argument('--version', dest='version',
+            action="store_true",
+            help=_("Print version and copyright info"))
     return parser
 
 class Tests:
@@ -167,6 +170,16 @@ class Tests:
     def __init__(self):
         self.festival_socket = None
 
+    def version(self):
+        """Print version and copyright info"""
+        report("spd-conf 0.9.1\n")
+        report(_("""Copyright (C) %d-%d Brailcom, o.p.s.
+This is free software; you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version. Please see COPYING for more details.\n\n""") % \
+               (2002, 2012))
+
     def user_conf_dir(self):
         """Return user configuration directory"""
         return os.path.join(BaseDirectory.xdg_config_home, "speech-dispatcher")
@@ -618,8 +631,11 @@ Do you want to keep it?"""), False)
         # Now determine the most important config option
         self.default_output_module = question_with_suggested_answers(
             "Default output module",
-            "espeak",
-            ["espeak", "flite", "festival", "cicero", "ibmtts"])
+            "espeak-ng",
+            ["espeak-ng", "espeak", "festival", "flite", "ivona", "pico", "espeak-generic",
+             "espeak-ng-mbrola-generic", "espeak-mbrola-generic", "swift-generic",
+             "epos-generic", "dtk-generic", "pico-generic", "ibmtts", "cicero", "kali",
+             "mary-generic", "baratinoo"])
 
         self.default_language = question(
             "Default language (two-letter iso language code like \"en\" or \"cs\")",
@@ -638,6 +654,9 @@ Do you want to keep it?"""), False)
             _("Default speech pitch (on the scale of -100..100, 0 is default, 50 is higher, -50 is lower)"),
             "0")
 
+        default_speech_pitch_range = question(
+            _("Default speech pitch range (on the scale of -100..100, 0 is default, 50 is higher, -50 is lower)"),
+            "0")
 
         # Substitute given configuration options
         if type == 'user':
@@ -651,6 +670,7 @@ Do you want to keep it?"""), False)
                                  "AudioOutputMethod": self.default_audio_method,
                                  "DefaultRate": default_speech_rate,
                                  "DefaultPitch": default_speech_pitch,
+                                 "DefaultPitchRange": default_speech_pitch_range,
                                  })
         if type == 'user':
             setup_autostart = question(
@@ -763,7 +783,8 @@ def main():
     configure = Configure(test) # that should possibly be refactored, test should not be passed
 
 
-    report(_("\nSpeech Dispatcher configuration tool\n"))
+    if not options.version:
+        report(_("\nSpeech Dispatcher configuration tool\n"))
 
     if options.create_user_configuration:
         # Check for and/or create basic user configuration
@@ -802,6 +823,9 @@ def main():
     elif options.debug:
         test.debug_and_report()
 
+    elif options.version:
+        test.version()
+
     else:
         reply = question(_("Do you want to setup a completely new configuration?"), True)
         if reply:
